@@ -22,14 +22,14 @@ import java.io.ByteArrayInputStream ;
 import java.io.ByteArrayOutputStream ;
 import java.io.PrintStream ;
 
+import java.lang.reflect.Method ;
+
 import groovy.util.GroovyTestCase ;
 
 import gant.Gant ;
 
 import org.codehaus.gant.GantState ;
 
-import org.codehaus.groovy.runtime.InvokerHelper ;
-
 /**
  *  A Gant test case: Adds the required input stream manipulation features to avoid replication of code.
  *  Also prepare a new instance of Gant for each test.
@@ -51,13 +51,41 @@ public abstract class GantTestCase extends GroovyTestCase {
   //  to the number with z being one higher than the last release.  So checkouts of maintenance branches
   //  will have x.y.z-SNAPSHOT, while from trunk numbers will be like x.y-beta-z-SNAPSHOT.
   //
+  //  From 2009-11-27, trunk now gives a number 1.8.0-beta-1-SNAPSHOT which adds further complexity to the
+  //  parsing :-(
+  //
   public enum ReleaseType { RELEASED, RELEASED_SNAPSHOT, BETA, BETA_SNAPSHOT, RC, RC_SNAPSHOT } ;
   public static final int groovyMajorVersion ;
   public static final int groovyMinorVersion ;
   public static final int groovyBugFixVersion ;
   public static final ReleaseType releaseType ;
   static {
-    final String[] version =  InvokerHelper.getVersion ( ).split ( "[.-]" ) ;
+    //
+    //  Originally we had:
+    //
+    //    final String[] version =  org.codehaus.groovy.runtime.InvokerHelper.getVersion ( ).split ( "[.-]" ) ;
+    //
+    //  but in Groovy 1.8 this method has been deprecated.  The method that must be called now is:
+    //
+    //    final String[] version =  groovy.lang.GroovySystem.getVersion ( ).split ( "[.-]" ) ;
+    //
+    //  which has actually been available since Groovy 1.6.  However, whilst the class
+    //  java.lang.GroovyStsrem exists in Groovy 1.5, the method does not in that version of Groovy.  We must
+    //  therefore use reflection to discover whether getVersion exists in the GroovySystem class and do the
+    //  right thing whatever situation pertains.
+    //
+    String[] version ;
+    try {
+      final Class<?> theClass = Class.forName ( "groovy.lang.GroovySystem" ) ;
+      final String methodName = "getVersion" ;
+      Method method ;
+      try { method = theClass.getMethod ( methodName ) ; }
+      catch ( final Exception e ) { method =  Class.forName ( "org.codehaus.groovy.runtime.InvokerHelper" ).getMethod ( methodName ) ; }
+      version = ( (String) ( method.invoke ( null ) ) ).split ( "[.-]" ) ;
+    }
+    catch ( final Exception e ) { throw new RuntimeException ( "Stuff", e ) ; }
+    //
+    //
     switch ( version.length ) {
      case 3 :
        groovyBugFixVersion =  Integer.parseInt ( version[2] ) ;
@@ -70,16 +98,26 @@ public abstract class GantTestCase extends GroovyTestCase {
        }
        else {
          groovyBugFixVersion =  Integer.parseInt ( version[3] ) ;
-         releaseType = version[2].equals ( "RC" ) ? ReleaseType.RC : ReleaseType.BETA ;
+         final String discriminator = version[2] ;
+         releaseType = ( discriminator.equals ( "RC" ) || discriminator.equals ( "rc" ) ) ? ReleaseType.RC : ReleaseType.BETA ;
        }
        break ;
-     case 5 :
-        groovyBugFixVersion =  Integer.parseInt ( version[3] ) ;
-        releaseType = version[2].equals ( "RC" ) ? ReleaseType.RC_SNAPSHOT : ReleaseType.BETA_SNAPSHOT ;
-        assert version[4] == "SNAPSHOT" ;
+     case 5 : {
+       groovyBugFixVersion =  Integer.parseInt ( version[3] ) ;
+       final String discriminator = version[2] ;
+       releaseType = ( discriminator.equals ( "RC" ) || discriminator.equals ( "rc" ) ) ? ReleaseType.RC_SNAPSHOT : ReleaseType.BETA_SNAPSHOT ;
+       assert version[4] == "SNAPSHOT" ;
        break ;
+     }
+     case 6 : {    
+       groovyBugFixVersion =  Integer.parseInt ( version[4] ) ;
+       final String discriminator = version[3] ;
+       releaseType = ( discriminator.equals ( "RC" ) || discriminator.equals ( "rc" ) ) ? ReleaseType.RC_SNAPSHOT : ReleaseType.BETA_SNAPSHOT ;
+       assert version[5] == "SNAPSHOT" ;
+       break ;
+     }
      default :
-       throw new RuntimeException ( "Groovy version number is not well-formed." ) ;
+      throw new RuntimeException ( "Groovy version number is not well-formed." ) ;
     }
     groovyMajorVersion = Integer.parseInt ( version[0] ) ;
     groovyMinorVersion = Integer.parseInt ( version[1] ) ;
